ARM: UniPhier: adjust device trees for business transfer

Panasonic's System LSI products, UniPhier SoC family, have been
transferred to Socionext Inc.

Signed-off-by: Masahiro Yamada <yamada.masahiro@socionext.com>
diff --git a/drivers/usb/host/xhci-uniphier.c b/drivers/usb/host/xhci-uniphier.c
index 08b15e0..e0ef322 100644
--- a/drivers/usb/host/xhci-uniphier.c
+++ b/drivers/usb/host/xhci-uniphier.c
@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2015 Panasonic Corporation
  *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -19,7 +20,7 @@
 	int count;
 
 	count = fdtdec_find_aliases_for_id(gd->fdt_blob, "usb",
-					   COMPAT_PANASONIC_XHCI, node_list,
+					   COMPAT_SOCIONEXT_XHCI, node_list,
 					   ARRAY_SIZE(node_list));
 
 	if (index >= count)
@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2015 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015 Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+